gnugo-devel
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[gnugo-devel] 9 stone games


From: bump
Subject: [gnugo-devel] 9 stone games
Date: Fri, 27 Sep 2002 07:35:27 -0700

The purpose of this patch is to tune the frequency with which
GNU Go plays various kakaris as white in 9 stone games. The game
regression/games/nngs/gnugo-3.3.8-Joorin-200209251541.sgf is a good
example of how badly GNU Go plays as white in 9 stone games.

For one thing, GNU currently always prefers the nikken takagakari
('c' below) to the more usual keima kakari. It will *never* play
keima kakari in a 9 stone game.

|..........
|..........
|...X.bc..X
|.....a....
|..........
|..........
+----------

Here 'a' is the best kakari. Although 'b' is playable
it is inferior to 'a' because it is badly placed when
W later goes to the 3-3- point. Better than 'b' is
'c' though GNU currently does not know how to follow
it up correctly.

After this patch I generated 50 moves at move 11 in
the Joorin game. I got the following distribution of moves:

'a' (C14, F17, O3 or R6) 26 times
'c' (D13, G16, N4 or Q7) 16 times
'b' (D14, O4 or Q6)      8  times

The key to the patch is to make these moves Fj patterns
so they can be tuned. The new patterns doing this have
X at the middle points so they have no effect on the
opening moves in 4 stone or even games.

Two elements of the patch may need discussion. I raised
the value of j patterns to 27. This is a guess and maybe
it's too high.

Also the randomization has been increased. I see no harm
in this but maybe it needs discussion.

- j value increased from 24 to 27
- randomization increased
- fuseki pattern tuning for 9 stone games


Index: engine/shapes.c
===================================================================
RCS file: /cvsroot/gnugo/gnugo/engine/shapes.c,v
retrieving revision 1.35
diff -u -r1.35 shapes.c
--- engine/shapes.c     27 Aug 2002 18:06:16 -0000      1.35
+++ engine/shapes.c     27 Sep 2002 14:22:22 -0000
@@ -34,7 +34,7 @@
 /* Values of joseki patterns. */
 #define U_VALUE 40.0
 #define J_VALUE 35.0
-#define j_VALUE 24.0
+#define j_VALUE 27.0
 #define t_VALUE 17.0
 
 
Index: patterns/fuseki.db
===================================================================
RCS file: /cvsroot/gnugo/gnugo/patterns/fuseki.db,v
retrieving revision 1.17
diff -u -r1.17 fuseki.db
--- patterns/fuseki.db  5 Aug 2002 23:42:15 -0000       1.17
+++ patterns/fuseki.db  27 Sep 2002 14:22:24 -0000
@@ -97,6 +97,9 @@
 ################
 
 
+#### Low (keima) kakari
+
+
 Pattern F1
 
 |..???...ooo   approach star
@@ -134,6 +137,33 @@
 :8,FeEat,shape(1)
 
 
+Pattern F3h
+# db added (3.3.9)
+
+|..........     keima kakari against star, high handicap game
+|...X.....x
+|.....*...x
+|..........
+|..........
++----------
+
+:8,FEj,shape(.025)
+
+|..........
+|...X.....a
+|.....*...b
+|..........
+|..........
++----------
+
+; x_somewhere(a,b)
+
+
+#### High (ikken taka) kakari
+#### not so good in relation to the corner since the
+####     3-3 point relationship is inferior.
+
+
 Pattern F4
 # Made attack dependent on extension space (3.1.25) /ab
 
@@ -159,6 +189,31 @@
 :8,FEa
 
 
+Pattern F5d
+# db added (3.3.9)
+
+|..........      high kakari against star
+|...X.*...x
+|.........x
+|..........
+|..........
++----------
+
+:8,FEj
+
+|..........
+|...X.*...a
+|.........b
+|..........
+|..........
++----------
+
+; x_somewhere(a,b)
+
+
+#### Two space high (nikken taka) kakari
+
+
 Pattern F5
 # Made attack dependent on extension space (3.1.25) /ab
 
@@ -182,6 +237,28 @@
 +-----------
 
 :8,FEa
+
+
+Pattern F5h
+# db added (3.3.9)
+
+|..........   far high kakari against star
+|...X..*..x
+|.........x
+|..........
+|..........
++----------
+
+:8,FEj,shape(.01)
+
+|..........
+|...X..*..a
+|.........b
+|..........
+|..........
++----------
+
+; x_somewhere(a,b)
 
 
 Pattern F6







reply via email to

[Prev in Thread] Current Thread [Next in Thread]
Index: engine/value_moves.c
===================================================================
RCS file: /cvsroot/gnugo/gnugo/engine/value_moves.c,v
retrieving revision 1.57
diff -u -r1.57 value_moves.c
--- engine/value_moves.c        26 Sep 2002 20:28:09 -0000      1.57
+++ engine/value_moves.c        27 Sep 2002 14:22:23 -0000
@@ -2539,8 +2539,8 @@
        * should reevaluate ko threats.
        */
       if (is_legal(pos, color) || is_illegal_ko_capture(pos, color)) {
-       /* Add a random number between 0 and 0.01 to use in comparisons. */
-       move[pos].value += 0.01 * move[pos].random_number;
+       /* Add a random number between 0 and 0.05 to use in comparisons. */
+       move[pos].value += 0.05 * move[pos].random_number;
       }
       else {
        move[pos].value = 0.0;